@@ -47,7 +47,7 @@ read_xml <- function(xml, pointer = TRUE, escapes = FALSE, declaration = FALSE,
   isvml <- grepl("^.vml$", xml)
 
   isfile <- FALSE
-  if (length(xml) == 1 && file.exists(xml))
+  if (length(xml) == 1 && !to_long(xml) && file.exists(xml))
     isfile <- TRUE
 
   if (!isfile)
