@@ -14,7 +14,7 @@ knitr::include_graphics("img/worksheet_styling.jpg")
 set.seed(123)
 mat <- matrix(rnorm(28 * 28, mean = 44444, sd = 555), ncol = 28)
 colnames(mat) <- make.names(seq_len(ncol(mat)))
-border_col <- wb_colour(theme = "1")
+border_col <- wb_color(theme = "1")
 border_sty <- "thin"
 
 # prepare workbook with data and formated first row
@@ -28,8 +28,8 @@ wb <- wb_workbook() %>%
     right_color = border_col, right_border = border_sty,
     inner_hcolor = border_col, inner_hgrid = border_sty
   ) %>%
-  wb_add_fill("test", "A1:AB1", color = wb_colour(hex = "FF334E6F")) %>%
-  wb_add_font("test", "A1:AB1", name = "Arial", bold = "1", color = wb_colour(hex = "FFFFFFFF"), size = "20") %>%
+  wb_add_fill("test", "A1:AB1", color = wb_color(hex = "FF334E6F")) %>%
+  wb_add_font("test", "A1:AB1", name = "Arial", bold = "1", color = wb_color(hex = "FFFFFFFF"), size = "20") %>%
   wb_add_cell_style("test", "A1:AB1", horizontal = "center", textRotation = "45")
 
 # create various number formats
@@ -69,11 +69,11 @@ wb$styles_mgr$add(new_border, "new_border")
 
 
 # create a fill style and assign it to the workbook
-new_fill <- create_fill(patternType = "solid", fgColor = wb_colour(hex = "FF334E6F"))
+new_fill <- create_fill(patternType = "solid", fgColor = wb_color(hex = "FF334E6F"))
 wb$styles_mgr$add(new_fill, "new_fill")
 
 # create a font style and assign it to the workbook
-new_font <- create_font(sz = "20", name = "Arial", b = "1", color = wb_colour(hex = "FFFFFFFF"))
+new_font <- create_font(sz = "20", name = "Arial", b = "1", color = wb_color(hex = "FFFFFFFF"))
 wb$styles_mgr$add(new_font, "new_font")
 
 # create a new cell style, that uses the fill, the font and the border style
@@ -120,7 +120,7 @@ wb$worksheets[[1]]$sheetPr <- xml_node_create(
   "sheetPr",
   xml_children = xml_node_create(
     "tabColor",
-    xml_attributes = wb_colour(hex = "FF00FF00")
+    xml_attributes = wb_color(hex = "FF00FF00")
   )
 )
 
@@ -297,9 +297,9 @@ for (i in 0:9) {
     col <- paste0(int2col(i + 1), which(tints %in% tnt))
 
     if (tnt == 0) {
-      wb <- wb %>% wb_add_fill(dims = col, color = wb_colour(theme = as.character(i)))
+      wb <- wb %>% wb_add_fill(dims = col, color = wb_color(theme = as.character(i)))
     } else {
-      wb <- wb %>% wb_add_fill(dims = col, color = wb_colour(theme = as.character(i), tint = tnt))
+      wb <- wb %>% wb_add_fill(dims = col, color = wb_color(theme = as.character(i), tint = tnt))
     }
   }
 }
