@@ -49,11 +49,9 @@ test_that("silent with numfmt option", {
   wb$add_worksheet("S2")
 
   wb$add_data_table("S1", x = iris)
-  expect_warning(
-    wb$add_data_table("S2",
-                 x = mtcars, xy = c("B", 3), rowNames = TRUE,
-                 tableStyle = "TableStyleLight9")
-  )
+  wb$add_data_table("S2",
+                    x = mtcars, dims = "B3", rowNames = TRUE,
+                    tableStyle = "TableStyleLight9")
 
   # [1:4] to ignore factor
   expect_equal(iris[1:4], wb_to_df(wb, "S1")[1:4], ignore_attr = TRUE)
@@ -236,8 +234,8 @@ test_that("update cell(s)", {
                         f_ca = c("", "", "", "", "", ""),
                         f_si = c("", "", "", "", "", ""),
                         is = c("", "", "", "", "", ""),
-                        typ = c("3", "3", "3", "3", "3", "3")),
-                   row.names = c("1", "8", "17", "114", "121", "128"),
+                        typ = c("4", "4", "4", "4", "4", "4")),
+                   row.names = 1:6,
                    class = "data.frame")
   got <- head(wb$worksheets[[1]]$sheet_data$cc)
   expect_equal(exp, got)
@@ -477,3 +475,37 @@ test_that("writing pivot tables works", {
   expect_equal(4L, length(wb$pivotTables))
 
 })
+
+test_that("writing na.strings = NULL works", {
+
+  # write na.strings = na_strings()
+  tmp <- temp_xlsx()
+  write_xlsx(matrix(NA, 2, 2), tmp)
+  wb <- wb_load(tmp)
+
+  exp <- "#N/A"
+  got <- unique(wb$worksheets[[1]]$sheet_data$cc$v[3:6])
+  expect_equal(exp, got)
+
+  # write na.strings = ""
+  tmp <- temp_xlsx()
+  write_xlsx(matrix(NA, 2, 2), tmp, na.strings = "")
+  wb <- wb_load(tmp)
+
+  exp <- "<is><t/></is>"
+  got <- unique(wb$worksheets[[1]]$sheet_data$cc$is[3:6])
+  expect_equal(exp, got)
+
+  # write na.strings = NULL
+  tmp <- temp_xlsx()
+  write_xlsx(matrix(NA, 2, 2), tmp, na.strings = NULL)
+  wb <- wb_load(tmp)
+
+  exp <- ""
+  got <- unique(wb$worksheets[[1]]$sheet_data$cc$v[3:6])
+  expect_equal(exp, got)
+
+  got <- unique(wb$worksheets[[1]]$sheet_data$cc$is[3:6])
+  expect_equal(exp, got)
+
+})
